@@ -78,7 +78,7 @@ ClientW::ClientW(QFrame *oParentFrame, int iFunction)
 
 	m_poCircuitFrame = new QFrame(this);
 	m_poCircuit = new Circuit();
-	m_poCircuit->newDevice(iFunction, 10, 10);
+	m_poCircuit->newDevice(iFunction, QPoint(10, 10));
 	m_poCircuitWidget = new NetWidget(m_poCircuitFrame, oParentFrame, m_poCircuit);
 	connect(m_poCircuitWidget, SIGNAL(autoMove(const QPoint&)), this, SLOT(autoMove(const QPoint&)));
 
