@@ -72,17 +72,7 @@ void Grid::draw( QPainter* p )
 //-- painting needs nearly 5 millisecs per device movement
 void Grid::draw( QPainter* p, QRect rc )
 {
-	bitBlt
-	(
-		p->device(),
-		rc.x(),
-		rc.y(),
-		&m_oGrid,
-		rc.x(),
-		rc.y(),
-		rc.width(),
-		rc.height()
-	);
+	bitBlt(p->device(), rc.x(), rc.y(), &m_oGrid, rc.x(), rc.y(), rc.width(), rc.height());
 }
 //---------------------------------------------------------------------
 
@@ -90,7 +80,7 @@ void Grid::draw( QPainter* p, QRect rc )
 //== grid alignment                                                  ==
 //=====================================================================
 //-- ptSrc	Coordinate to align
-QPoint Grid::getAligned( QPoint ptSrc )
+QPoint Grid::getAligned(const QPoint& ptSrc)
 {
 	// Align to the same grid size in x and y direction
 	QPoint ptReturn = ( ptSrc / Grid::GRID ) * Grid::GRID;
@@ -99,7 +89,7 @@ QPoint Grid::getAligned( QPoint ptSrc )
 }
 //---------------------------------------------------------------------
 //-- rcSrc	Coordinate to align
-QRect Grid::getAligned( QRect rcSrc )
+QRect Grid::getAligned(const QRect& rcSrc)
 {
 	QRect 	rcReturn 	= rcSrc;
 
