@@ -104,7 +104,7 @@ InverterWidget::InverterWidget(QWidget *parent, const char *name, XDevice *_dev)
 	setBackgroundMode(PaletteBase);
 	setBackgroundColor(white);
 
-	for (i = 0; i < XDevice::MAXSIZE;i++) {
+	for (i = 0; i < Global::Device::MAXSIZE;i++) {
 		iswitch[i] = (QCheckBox *)NULL;
 		oswitch[i] = (QCheckBox *)NULL;
 	}
@@ -125,8 +125,8 @@ void InverterWidget::paintEvent(QPaintEvent *)
 {	QPainter p;
 
 	erase();
-	QPixmap *pix = dev->getImage();
-	bitBlt(this, (rect().width() - pix->width()) / 2, 15 , pix);
+	const Image *poImage = dev->getImage();
+	bitBlt(this, (rect().width() - poImage->width()) / 2, 15 , poImage);
 
 	p.begin(this);
 	p.setPen(black);
@@ -161,7 +161,7 @@ void InverterWidget::setInputButtons()
 {	int i = 0;
 	int j, idx;
 	QPoint pt;
-	QRect re = dev->getPos();
+	QPoint re = dev->getPos();
 	int y;
 	KlogicList<XWire> *lw = dev->getIRef()->First();
 	XWire *w;
@@ -169,7 +169,7 @@ void InverterWidget::setInputButtons()
 
 	if (bg_i) {
 		disconnect(bg_i, SIGNAL(clicked(int)), this, SLOT(inputButton(int)));
-		for (i = 0; i < XDevice::MAXSIZE;i++) {
+		for (i = 0; i < Global::Device::MAXSIZE;i++) {
 			delete iswitch[i];
 			iswitch[i] = (QCheckBox *)NULL;
 			iwire[i].Destroy();
@@ -214,7 +214,7 @@ void InverterWidget::setOutputButtons()
 {	int i = 0;
 	int j, idx;
 	QPoint pt;
-	QRect re = dev->getPos();
+	QPoint re = dev->getPos();
 	int y;
 	KlogicList<XWire> *lw = dev->getORef()->First();
 	XWire *w;
@@ -222,7 +222,7 @@ void InverterWidget::setOutputButtons()
 
 	if (bg_o) {
 		disconnect(bg_o, SIGNAL(clicked(int)), this, SLOT(outputButton(int)));
-		for (i = 0; i < XDevice::MAXSIZE;i++) {
+		for (i = 0; i < Global::Device::MAXSIZE;i++) {
 			delete oswitch[i];
 			oswitch[i] = (QCheckBox *)NULL;
 			owire[i].Destroy();
