@@ -108,10 +108,7 @@ void klogicIO::setSubFilename()
 
 bool klogicIO::write(bool subnet, bool selected, int dx, int dy)
 {
-	if (file_format == SAVE_XML)
-		return writeXML(subnet, selected, dx, dy);
-	else
-		return writeNet(subnet, selected, dx, dy);
+	return writeXML(subnet, selected, dx, dy);
 }
 
 bool klogicIO::writeXML(bool subnet, bool selected, int dx, int dy)
@@ -148,6 +145,7 @@ bool klogicIO::writeXML(QTextStream &ts, bool subnet, bool selected, int dx, int
 	header.setAuthor(Global::CurrentCircuit::author);
 	header.setComment(Global::CurrentCircuit::comment);
 
+	ts << XmlObject::XML_ROOT;
 	ts << header.getFieldStart();
 	ts << header.getFieldContent();
 
@@ -180,30 +178,6 @@ bool klogicIO::readXML(QTextStream& t, bool selected, int dx = 0, int dy = 0)
 	return XMLImportHandler::import(net, selected, dx, dy, t);
 }
 
-bool klogicIO::writeNet(bool subnet, bool selected, int dx, int dy)
-{
-	if (!net) return false;
-	if (fname.isEmpty()) return false;
-
-	QFile f(fname);
-	if (!f.open(IO_WriteOnly|IO_Truncate))
-		return false;
-
-	QTextStream ts(&f);
-
-	bool ret = writeNet(ts, subnet, selected, dx, dy);
-
-	f.flush();
-	f.close();
-	return ret;
-}
-
-bool klogicIO::writeNet(QTextStream &ts, bool subnet, bool selected, int dx, int dy)
-{
-	// export the circuit
-	return net->exportNet(ts, selected, subnet, dx, dy);
-}
-
 bool klogicIO::readNet(bool create_sub)
 {
 	if (!net) return false;
