@@ -25,13 +25,11 @@
 #include <qslider.h>
 #include <qcombobox.h>
 
-#include "xwire.h"
 #include "mainw.h"
 #include "netw.h"
 #include "klogic.h"
 #include "klogicIO.h"
 #include "version.h"
-#include "xdevice.h"
 #include "clientw.h"
 #include "simw.h"
 #include "propGlob.h"
@@ -82,7 +80,7 @@ void MainWidget::setPATH(KApplication *app)
 /* methods of class MainWidget                     */
 /***************************************************/
 MainWidget::MainWidget(KApplication *_app, const char *file)
-	:KMainWindow(NULL)
+	:KMainWindow()
 {
 	app = _app;
 	setPATH(app);
@@ -94,9 +92,6 @@ MainWidget::MainWidget(KApplication *_app, const char *file)
 	// read config
 	readProperties(app->config());
 
-	// load device pixmaps
-	XDevice::loadPix();
-
 	// initial net
 	ClientW *client_widget = new ClientW(this, file);
 	client_widgets.Append(client_widget);
@@ -213,11 +208,21 @@ void MainWidget::initToolbar()
 			this, SLOT(menuCallback(int)), TRUE, i18n("AND gate"), -1);
 	gate_toolbar->setToggle(DeviceType::fAND, TRUE);
 
+	px.load(TBPATH + "tbNAND.xpm");
+	gate_toolbar->insertButton(px, DeviceType::fNAND, SIGNAL(clicked(int)),
+			this, SLOT(menuCallback(int)), TRUE, i18n("NAND gate"), -1);
+	gate_toolbar->setToggle(DeviceType::fNAND, TRUE);
+
 	px.load(TBPATH + "tbOR.xpm");
 	gate_toolbar->insertButton(px, DeviceType::fOR, SIGNAL(clicked(int)),
 			this, SLOT(menuCallback(int)), TRUE, i18n("OR gate"), -1);
 	gate_toolbar->setToggle(DeviceType::fOR, TRUE);
 
+	px.load(TBPATH + "tbNOR.xpm");
+	gate_toolbar->insertButton(px, DeviceType::fNOR, SIGNAL(clicked(int)),
+			this, SLOT(menuCallback(int)), TRUE, i18n("NOR gate"), -1);
+	gate_toolbar->setToggle(DeviceType::fNOR, TRUE);
+
 	px.load(TBPATH + "tbINV.xpm");
 	gate_toolbar->insertButton(px, DeviceType::fONE, SIGNAL(clicked(int)),
 			this, SLOT(menuCallback(int)), TRUE, i18n("inverter"), -1);
@@ -243,6 +248,11 @@ void MainWidget::initToolbar()
 			this, SLOT(menuCallback(int)), TRUE, i18n("JK flipflop"), -1);
 	gate_toolbar->setToggle(DeviceType::fJK, TRUE);
 
+	px.load(TBPATH + "tbT.xpm");
+	gate_toolbar->insertButton(px, DeviceType::fTFF, SIGNAL(clicked(int)),
+			this, SLOT(menuCallback(int)), TRUE, i18n("T flipflop"), -1);
+	gate_toolbar->setToggle(DeviceType::fTFF, TRUE);
+
 	px.load(TBPATH + "tbRAM.xpm");
 	gate_toolbar->insertButton(px, DeviceType::fRAM, SIGNAL(clicked(int)),
 			this, SLOT(menuCallback(int)), TRUE, i18n("RAM 32x8"), -1);
@@ -269,9 +279,9 @@ void MainWidget::initToolbar()
 	gate_toolbar->setToggle(DeviceType::fSS, TRUE);
 
 	px.load(TBPATH + "tbLED.xpm");
-	gate_toolbar->insertButton(px, DeviceType::fLEDgreen, SIGNAL(clicked(int)),
+	gate_toolbar->insertButton(px, DeviceType::fLED, SIGNAL(clicked(int)),
 			this, SLOT(menuCallback(int)), TRUE, i18n("LED"), -1);
-	gate_toolbar->setToggle(DeviceType::fLEDgreen, TRUE);
+	gate_toolbar->setToggle(DeviceType::fLED, TRUE);
 
 /*
 	px.load(TBPATH + "tbMatrix.xpm");
@@ -384,13 +394,17 @@ void MainWidget::initToolbar()
 // exchange toolbar pixmaps depending on the used device symbolset
 void MainWidget::setToolbarPixmap()
 {	QPixmap px;
-	int symbolset = XDevice::getSymbolSet();
+	int symbolset = Global::Device::getSymbolSet();
 
-	if (symbolset == XDevice::SYMBOLSET_DIN40900) {
+	if (symbolset == Global::Device::SYMBOLSET_DIN40900) {
 		px.load(TBPATH + "tbAND.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fAND, px);
+		px.load(TBPATH + "tbNAND.xpm");
+		gate_toolbar->setButtonPixmap(DeviceType::fNAND, px);
 		px.load(TBPATH + "tbOR.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fOR, px);
+		px.load(TBPATH + "tbNOR.xpm");
+		gate_toolbar->setButtonPixmap(DeviceType::fNOR, px);
 		px.load(TBPATH + "tbXOR.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fXOR, px);
 		px.load(TBPATH + "tbINV.xpm");
@@ -398,8 +412,12 @@ void MainWidget::setToolbarPixmap()
 	} else {
 		px.load(TBPATH + "tbIECAND.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fAND, px);
+		px.load(TBPATH + "tbIECNAND.xpm");
+		gate_toolbar->setButtonPixmap(DeviceType::fNAND, px);
 		px.load(TBPATH + "tbIECOR.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fOR, px);
+		px.load(TBPATH + "tbIECNOR.xpm");
+		gate_toolbar->setButtonPixmap(DeviceType::fNOR, px);
 		px.load(TBPATH + "tbIECXOR.xpm");
 		gate_toolbar->setButtonPixmap(DeviceType::fXOR, px);
 		px.load(TBPATH + "tbIECINV.xpm");
@@ -445,8 +463,10 @@ void MainWidget::initMenubar()
 	pm_logic->setAccel(Key_E + CTRL, DeviceType::fEQU);
 	pm_logic->insertItem(i18n("&AND"), DeviceType::fAND);
 	pm_logic->setAccel(Key_A + CTRL, DeviceType::fAND);
+	pm_logic->insertItem(i18n("NA&ND"), DeviceType::fNAND);
 	pm_logic->insertItem(i18n("&OR"), DeviceType::fOR);
 	pm_logic->setAccel(Key_O + CTRL, DeviceType::fOR);
+	pm_logic->insertItem(i18n("NOR"), DeviceType::fNOR);
 	pm_logic->insertItem(i18n("&XOR"), DeviceType::fXOR);
 	pm_logic->setAccel(Key_X + CTRL, DeviceType::fXOR);
 	pm_logic->insertItem(i18n("&Inverter"), DeviceType::fONE);
@@ -457,6 +477,8 @@ void MainWidget::initMenubar()
 	pm_logic->setAccel(Key_D+ CTRL, DeviceType::fDFF);
 	pm_logic->insertItem(i18n("&JK flipflop"), DeviceType::fJK);
 	pm_logic->setAccel(Key_J+ CTRL, DeviceType::fJK);
+	pm_logic->insertItem(i18n("&T flipflop"), DeviceType::fTFF);
+	pm_logic->setAccel(Key_T+ CTRL, DeviceType::fTFF);
 	pm_logic->insertItem(i18n("RA&M 32x8"), DeviceType::fRAM);
 	pm_logic->setAccel(Key_M+ CTRL, DeviceType::fRAM);
 	pm_logic->insertItem(i18n("Tristate output"), DeviceType::fTRI);
@@ -469,8 +491,8 @@ void MainWidget::initMenubar()
 	pm_logic->setAccel(Key_S+ CTRL, DeviceType::fSWI);
 	pm_logic->insertItem(i18n("&7-Segment"), DeviceType::fSS);
 	pm_logic->setAccel(Key_7+ CTRL, DeviceType::fSS);
-	pm_logic->insertItem(i18n("&LED"), DeviceType::fLEDgreen);
-	pm_logic->setAccel(Key_L+ CTRL, DeviceType::fLEDgreen);
+	pm_logic->insertItem(i18n("&LED"), DeviceType::fLED);
+	pm_logic->setAccel(Key_L+ CTRL, DeviceType::fLED);
 /*
 	pm_logic->insertItem(i18n("Matrix"), DeviceType::fMATRIX);
 */
@@ -544,19 +566,22 @@ void MainWidget::menuCallback(int id)
 	switch(id) {
 		case DeviceType::fEQU:
 		case DeviceType::fAND:
+		case DeviceType::fNAND:
 		case DeviceType::fOR:
+		case DeviceType::fNOR:
 		case DeviceType::fXOR:
 		case DeviceType::fONE:
 		case DeviceType::fRS:
 		case DeviceType::fDFF:
 		case DeviceType::fJK:
+		case DeviceType::fTFF:
 		case DeviceType::fRAM:
 		case DeviceType::fTRI:
 		case DeviceType::fBUS:
 		case DeviceType::fSS:
 		case DeviceType::fOSC:
 		case DeviceType::fSWI:
-		case DeviceType::fLEDgreen:
+		case DeviceType::fLED:
 		case DeviceType::fMATRIX:
 		case DeviceType::fIN:
 		case DeviceType::fOUT:
@@ -707,8 +732,12 @@ void MainWidget::turnAllCheckButton(int id)
 	menubar->setItemChecked(DeviceType::fEQU, FALSE);
 	gate_toolbar->setButton(DeviceType::fAND, FALSE);
 	menubar->setItemChecked(DeviceType::fAND, FALSE);
+	gate_toolbar->setButton(DeviceType::fNAND, FALSE);
+	menubar->setItemChecked(DeviceType::fNAND, FALSE);
 	gate_toolbar->setButton(DeviceType::fOR, FALSE);
 	menubar->setItemChecked(DeviceType::fOR, FALSE);
+	gate_toolbar->setButton(DeviceType::fNOR, FALSE);
+	menubar->setItemChecked(DeviceType::fNOR, FALSE);
 	gate_toolbar->setButton(DeviceType::fXOR, FALSE);
 	menubar->setItemChecked(DeviceType::fXOR, FALSE);
 	gate_toolbar->setButton(DeviceType::fONE, FALSE);
@@ -721,6 +750,8 @@ void MainWidget::turnAllCheckButton(int id)
 	menubar->setItemChecked(DeviceType::fRS, FALSE);
 	gate_toolbar->setButton(DeviceType::fJK, FALSE);
 	menubar->setItemChecked(DeviceType::fJK, FALSE);
+	gate_toolbar->setButton(DeviceType::fTFF, FALSE);
+	menubar->setItemChecked(DeviceType::fTFF, FALSE);
 	gate_toolbar->setButton(DeviceType::fRAM, FALSE);
 	menubar->setItemChecked(DeviceType::fRAM, FALSE);
 	gate_toolbar->setButton(DeviceType::fTRI, FALSE);
@@ -731,8 +762,8 @@ void MainWidget::turnAllCheckButton(int id)
 	menubar->setItemChecked(DeviceType::fOSC, FALSE);
 	gate_toolbar->setButton(DeviceType::fSWI, FALSE);
 	menubar->setItemChecked(DeviceType::fSWI, FALSE);
-	gate_toolbar->setButton(DeviceType::fLEDgreen, FALSE);
-	menubar->setItemChecked(DeviceType::fLEDgreen, FALSE);
+	gate_toolbar->setButton(DeviceType::fLED, FALSE);
+	menubar->setItemChecked(DeviceType::fLED, FALSE);
 	gate_toolbar->setButton(DeviceType::fMATRIX, FALSE);
 	menubar->setItemChecked(DeviceType::fMATRIX, FALSE);
 	gate_toolbar->setButton(DeviceType::fIN, FALSE);
@@ -830,24 +861,24 @@ void MainWidget::readProperties(KConfig *config)
 	Global::Screen::VIRT_SCREEN_SIZE_Y = ret;
 
 	config->setGroup("device");
-	ret = config->readNumEntry("size", XDevice::defSize());
-	XDevice::setDefSize(ret);
-	ret = config->readNumEntry("width", XDevice::defWidth());
-	XDevice::setDefWidth(ret);
-	ret = config->readNumEntry("delay", Device::defDelay());
-	Device::setDefDelay(ret);
-	ret = config->readNumEntry("undefined", Device::defUndefined());
-	Device::setDefUndefined(ret);
-	ret = config->readNumEntry("invert", XDevice::isDefInverted());
-	XDevice::setDefInverted(ret);
-	ret = config->readNumEntry("nameDisplayed", XDevice::nameDisplayedGlobal());
-	XDevice::displayNameGlobal(ret);
-	QString fnt = config->readEntry("device_font", XDevice::getFont());
-	XDevice::setFont(fnt);
-	ret = config->readNumEntry("device_font_size", XDevice::getFontSize());
-	XDevice::setFontSize(ret);
-	ret = config->readNumEntry("device_symbolset", XDevice::getSymbolSet());
-	XDevice::setSymbolSet(ret);
+	ret = config->readNumEntry("size", Global::Device::getSize());
+	Global::Device::setSize(ret);
+	ret = config->readNumEntry("width", Global::Device::getWidth());
+	Global::Device::setWidth(ret);
+	ret = config->readNumEntry("delay", Global::Device::getDelay());
+	Global::Device::setDelay(ret);
+	ret = config->readNumEntry("undefined", Global::Device::getUndefinedValue());
+	Global::Device::setUndefinedValue(ret);
+	ret = config->readNumEntry("invert", Global::Device::isInverted());
+	Global::Device::setInverted(ret);
+	ret = config->readNumEntry("nameDisplayed", Global::Device::isDisplayNames());
+	Global::Device::setDisplayNames(ret);
+	QString fnt = config->readEntry("device_font", Global::Device::getFontFamily());
+	Global::Device::setFontFamily(fnt);
+	ret = config->readNumEntry("device_font_size", Global::Device::getFontSize());
+	Global::Device::setFontSize(ret);
+	ret = config->readNumEntry("device_symbolset", Global::Device::getSymbolSet());
+	Global::Device::setSymbolSet(ret);
 
 	config->setGroup("simulation");
 	ret = config->readNumEntry("time", NetWidget::simTime());
@@ -856,10 +887,8 @@ void MainWidget::readProperties(KConfig *config)
 	NetWidget::setSimBurst(ret);
 
 	config->setGroup("pulsed");
-	ret = config->readNumEntry("clock", Device::defClock());
-	Device::setDefClock(ret);
-	ret = config->readNumEntry("reverse_trigger", Device::triggerInverted());
-	Device::invertTrigger(ret);
+	Global::Device::CLOCKTYPE iClock = (Global::Device::CLOCKTYPE)config->readNumEntry("clock", Global::Device::getClock());
+	Global::Device::setClock(iClock);
 	ret = config->readNumEntry("file_format", klogicIO::getSaveFileFormat());
 	klogicIO::setSaveFileFormat(ret);
 }
@@ -867,23 +896,22 @@ void MainWidget::readProperties(KConfig *config)
 void MainWidget::saveProperties(KConfig *config)
 {
 	config->setGroup("device");
-	config->writeEntry("size", XDevice::defSize());
-	config->writeEntry("width", XDevice::defWidth());
-	config->writeEntry("delay", Device::defDelay());
-	config->writeEntry("undefined", Device::defUndefined());
-	config->writeEntry("invert", XDevice::isDefInverted());
-	config->writeEntry("nameDisplayed", XDevice::nameDisplayedGlobal());
-	config->writeEntry("device_font", XDevice::getFont());
-	config->writeEntry("device_font_size", XDevice::getFontSize());
-	config->writeEntry("device_symbolset", XDevice::getSymbolSet());
+	config->writeEntry("size", Global::Device::getSize());
+	config->writeEntry("width", Global::Device::getWidth());
+	config->writeEntry("delay", Global::Device::getDelay());
+	config->writeEntry("undefined", Global::Device::getUndefinedValue());
+	config->writeEntry("invert", Global::Device::isInverted());
+	config->writeEntry("nameDisplayed", Global::Device::isDisplayNames());
+	config->writeEntry("device_font", Global::Device::getFontFamily());
+	config->writeEntry("device_font_size", Global::Device::getFontSize());
+	config->writeEntry("device_symbolset", Global::Device::getSymbolSet());
 
 	config->setGroup("simulation");
 	config->writeEntry("time", NetWidget::simTime());
 	config->writeEntry("burst", NetWidget::simBurst());
 
 	config->setGroup("pulsed");
-	config->writeEntry("clock", Device::defClock());
-	config->writeEntry("reverse_trigger", Device::triggerInverted());
+	config->writeEntry("clock", Global::Device::getClock());
 	config->writeEntry("file_format", klogicIO::getSaveFileFormat());
 	config->sync();
 }
