@@ -27,7 +27,7 @@ QBuffer Selection::copy_buffer;
 
 Selection::Selection()
 {
-	net = (Circuit *)NULL;
+	m_poCircuit = 0;
 	selstat = SEL_EMPTY;
 	frame_moved = 0;
 	tempdev = (XDevice *)NULL;
@@ -60,10 +60,10 @@ Selection::~Selection()
 	wire.Destroy();
 }
 
-// set parent net for a selection
-void Selection::setNet(Circuit *_net)
+// set parent poCircuit for a selection
+void Selection::setNet(Circuit *poCircuit)
 {
-	net = _net;
+	m_poCircuit = poCircuit;
 }
 
 // add a device to the current selection
@@ -163,8 +163,8 @@ void Selection::beginFrame(QPoint newp)
 	setFrame(corner1);
 	old_frame = frame;
 
-	net->selectDev(frame, &dev);
-	net->selectWire(frame, &wire);
+	m_poCircuit->selectDev(frame, &dev);
+	m_poCircuit->selectWire(frame, &wire);
 
 	selstat = SEL_START;
 }
@@ -177,8 +177,8 @@ void Selection::changeFrame(QPoint newp)
 	setFrame(newp);
 
 	if (old_frame != frame) {
-		net->selectDev(frame, &dev);
-		net->selectWire(frame, &wire);
+		m_poCircuit->selectDev(frame, &dev);
+		m_poCircuit->selectWire(frame, &wire);
 	}
 }
 
@@ -256,14 +256,14 @@ void Selection::moveFrame(QPoint pt, QPainter *p)
 	// ** move wires
 	lw = wire.First();
 	while(lw) {
-		lw->Get()->addPos(dx, dy);
+		lw->Get()->moveBy(QPoint(dx, dy));
 		lw = lw->Next();
 	}
 
 	// ** move devices
 	ld = dev.First();
 	while(ld) {
-		ld->Get()->addPos(dx, dy);
+		ld->Get()->moveBy(QPoint(dx, dy));
 		ld = ld->Next();
 	}
 
@@ -296,31 +296,29 @@ void Selection::endMove()
 }
 
 // cut selection
-void Selection::cut(QPainter *p, Circuit *net)
-{	KlogicList<XDevice> *ld;
-	KlogicList<XWire> *lw;
-
+void Selection::cut(QPainter *p, Circuit *poCircuit)
+{
 	if (selstat != SEL_EXISTS) return;
 
 	// ** first copy the current selection into the copy-buffer
-	copy(net);
+	copy(poCircuit);
 
 	// ** erase wires
-	lw = wire.First();
+	KlogicList<XWire> *lw = wire.First();
 	while(lw) {
 		lw->Get()->XWire::eraseWire(p);
 		lw = lw->Next();
 	}
 
-	// ** now remove the objects from the net
-	ld = dev.First();
+	// ** now remove the objects from the poCircuit
+	KlogicList<XDevice> *ld = dev.First();
 	while(ld) {
-		net->deleteDevice(p, ld->Get());
+		poCircuit->deleteDevice(p, ld->Get());
 		ld = ld->Next();
 	}
 	lw = wire.First();
 	while(lw) {
-		net->deleteWire(lw->Get());
+		poCircuit->deleteWire(lw->Get());
 		lw = lw->Next();
 	}
 
@@ -330,26 +328,24 @@ void Selection::cut(QPainter *p, Circuit *net)
 
 // copy selection into the copy-buffer
 // copy_buffer contains a normal klogic file format
-void Selection::copy(Circuit *net)
-{	KlogicList<XDevice> *ld;
-	KlogicList<XWire> *lw;
-	int minx = 999999, miny = 999999;
-	QRect r;
-	int a;
+void Selection::copy(Circuit *poCircuit)
+{
+	if (selstat != SEL_EXISTS)
+		return;
 
-	if (selstat != SEL_EXISTS) return;
+	int minx = 999999, miny = 999999;
 
 	// detemine minimum coodinates of the selection
-	ld = dev.First();
+	KlogicList<XDevice> *ld = dev.First();
 	while(ld) {
-		r = ld->Get()->getPos();
-		if (r.x() < minx) minx = r.x();
-		if (r.y() < miny) miny = r.y();
+		QPoint oPos = ld->Get()->getPos();
+		if (oPos.x() < minx) minx = oPos.x();
+		if (oPos.y() < miny) miny = oPos.y();
 		ld = ld->Next();
 	}
-	lw = wire.First();
+	KlogicList<XWire> *lw = wire.First();
 	while(lw) {
-		a = lw->Get()->getMinSelX();
+		int a = lw->Get()->getMinSelX();
 		if (a < minx) minx = a;
 		a = lw->Get()->getMinSelY();
 		if (a < miny) miny = a;
@@ -362,7 +358,7 @@ void Selection::copy(Circuit *net)
 	// export objects relative to minx/miny as zero-coord.
 	copy_buffer.open(IO_WriteOnly|IO_Truncate);
 	QTextStream ts(&copy_buffer);
-	klogicIO io(net);
+	klogicIO io(poCircuit);
 
 	// save as main circuit: ignore the very first circuit
 	io.writeXML(ts, false, true, minx, miny);
@@ -378,7 +374,7 @@ void Selection::at(QPoint pt)
 }
 
 // paste selection from the copy buffer
-void Selection::paste(QPainter *p, Circuit *net)
+void Selection::paste(QPainter *p, Circuit *poCircuit)
 {
 	// ** remove the current selection
 	remove(p, 1);
@@ -387,11 +383,11 @@ void Selection::paste(QPainter *p, Circuit *net)
 	// ++ all pasted objects automaticly become status "selected"
 	copy_buffer.open(IO_ReadOnly);
 	QTextStream ts(&copy_buffer);
-	klogicIO io(net);
+	klogicIO io(poCircuit);
 	io.readXML(ts, SELECT_IT, paste_at.x(), paste_at.y());
 	copy_buffer.close();
 
-	net->grabSelection(this);	// something like recursive call to this->add(..)
+	poCircuit->grabSelection(this);	// something like recursive call to this->add(..)
 	if (dev.counter()==0 && wire.counter() == 0) remove();
 	else selstat = SEL_EXISTS;
 	setFrame();
@@ -418,28 +414,25 @@ inline void Selection::setFrame(QPoint corner2)
 
 // set dimension of the group selection frame in dependance of all selected objects
 inline void Selection::setFrame()
-{	KlogicList<XDevice> *ld;
-	KlogicList<XWire> *lw;
-	int minx = 999999, miny = 999999;
-	int maxx = 0, maxy = 0;
-	QRect r;
-	int a;
-
+{
 	if (selstat == SEL_EMPTY) return;
 
+	int minx = 999999, miny = 999999;
+	int maxx = 0, maxy = 0;
+
 	// detemine minimum/maximum coodinates of the selection
-	ld = dev.First();
+	KlogicList<XDevice> *ld = dev.First();
 	while(ld) {
-		r = ld->Get()->getPos();
-		if (r.x() < minx) minx = r.x();
-		if (r.x() + r.width() > maxx) maxx = r.x() + r.width();
-		if (r.y() < miny) miny = r.y();
-		if (r.y() + r.height() > maxy) maxy = r.y() + r.height();
+		const QRect& oGeo = ld->Get()->getGeometry();
+		if (oGeo.x() < minx) minx = oGeo.x();
+		if (oGeo.x() + oGeo.width() > maxx) maxx = oGeo.x() + oGeo.width();
+		if (oGeo.y() < miny) miny = oGeo.y();
+		if (oGeo.y() + oGeo.height() > maxy) maxy = oGeo.y() + oGeo.height();
 		ld = ld->Next();
 	}
-	lw = wire.First();
+	KlogicList<XWire> *lw = wire.First();
 	while(lw) {
-		a = lw->Get()->getMinSelX();
+		int a = lw->Get()->getMinSelX();
 		if (a < minx) minx = a;
 		a = lw->Get()->getMaxSelX();
 		if (a > maxx) maxx = a;
