@@ -19,6 +19,7 @@
 /* methods of XWire (connection between devices)  */
 /***************************************************/
 int XWire::instance = 0;
+DeviceFactory * XWire::m_poDeviceFactory = DeviceFactory::getInstance();
 
 XWire::XWire()
 	:Wire()
@@ -228,25 +229,6 @@ int XWire::createNode(QPoint p)
 	return ret;
 }
 
-void XWire::updateNode(QPoint p)
-{	int idx;
-
-	// node contains the old position of the point
-	if (WFAIL != (idx = Wire::activeIsInput()))
-		in_dev[idx]->eraseConnectionLines();
-	if (WFAIL != (idx = Wire::activeIsOutput()))
-		out_dev[idx]->eraseConnectionLines();
-
-	// update the node
-	Wire::updateNode(p);
-
-	// node contains the new position of the point
-	if (WFAIL != (idx = Wire::activeIsInput()))
-		in_dev[idx]->drawConnectionLines();
-	if (WFAIL != (idx = Wire::activeIsOutput()))
-		out_dev[idx]->drawConnectionLines();
-} 
-
 // device-wire-connections: first diconnect devices, then remove node
 // wire-wire-connections  : make a disconnect from the wire which holds a copy
 XWire * XWire::removeNode()
@@ -280,16 +262,6 @@ XWire * XWire::removeNode()
 	return (XWire *)NULL;
 }
 
-void XWire::releaseNode()
-{	int idx;
-
-	if (WFAIL != (idx = activeIsInput()))
-		in_dev[idx]->drawConnectionLines();
-	if (WFAIL != (idx = activeIsOutput()) && out_dev[idx])
-		out_dev[idx]->drawConnectionLines();
-	Wire::releaseNode();
-}
-
 // returns error if connected already, 1 if succesful
 // pay attention to the inverters on device-level!
 // if invert is set, invertation is forced
@@ -309,7 +281,7 @@ int XWire::connectInput(XDevice *dev, int invert, int device_id)
 	else if (!bSlot1Connected)
 		idx = 1;
 	else {
-		fprintf(stderr, "XWire::connectOutput() connection failed!\n");
+		cerr << "XWire::connectOutput() connection failed!\n" << endl;
 		return WFAIL;
 	}
 
@@ -325,7 +297,7 @@ int XWire::connectInput(XDevice *dev, int invert, int device_id)
 	else input_is_inv[idx] = 0;
 
 	// add reference to this wire in device
-	in_dev[idx]->addInput(this, idx);
+	in_dev[idx]->addInputWire(this);
 
 	setDeviceConnections(CONNECT, idx);
 	return WOK;
@@ -339,7 +311,7 @@ void XWire::disconnectInput(int idx)
 	setDeviceConnections(DISCONN, idx);
 
 	// remove reference to this wire in device
-	in_dev[idx]->removeInput(this, idx);
+	in_dev[idx]->removeInputWire(this);
 
 	// remove point-reverence, connected to
 	Wire::disconnectInput(idx);
@@ -370,7 +342,7 @@ int XWire::connectOutput(XDevice *dev, int invert, int device_id)
 	else if (!bSlot1Connected)
 		idx = 1;
 	else {
-		fprintf(stderr, "XWire::connectOutput() connection failed!\n");
+		cerr << "XWire::connectOutput() connection failed!\n" << endl;
 		return WFAIL;
 	}
 
@@ -387,7 +359,7 @@ int XWire::connectOutput(XDevice *dev, int invert, int device_id)
 	else output_is_inv[idx] = out_dev[idx]->isInverted();
 
 	// add reference to this wire in device
-	out_dev[idx]->addOutput(this, idx);
+	out_dev[idx]->addOutputWire(this);
 
 	resetScan(START);
 	scanOutputDev();	// find/distribute all output devices
@@ -405,7 +377,7 @@ int XWire::connectOutput(XDevice *dev, int invert, int device_id)
 void XWire::disconnectOutput(int idx)
 {
 	// remove reference to this wire in device
-	out_dev[idx]->removeOutput(this, idx);
+	out_dev[idx]->removeOutputWire(this);
 
 	// remove point-reference (not longer output-point)
 	Wire::disconnectOutput(idx);
@@ -439,13 +411,18 @@ void XWire::invertInput(XDevice *d, bool set)
 	setDeviceConnections(CONNECT, idx);
 }
 
-int XWire::inputIsInverted(XDevice *dev)
+bool XWire::inputIsInverted(XDevice *dev)
 {	int idx;
 
 	if (WFAIL == (idx = getInputIndex(dev))) fatal("XWire::inputIsInverted: unknown device");
 	return input_is_inv[idx];
 }
 
+bool XWire::inputIsInverted(int idx)
+{
+	return input_is_inv[idx];
+}
+
 void XWire::invertOutput(XDevice *dev, bool set)
 {	int idx;
 
@@ -470,13 +447,18 @@ void XWire::invertOutput(XDevice *dev, bool set)
 	scanOutputDev();	// find/distribute all output devices
 }
 
-int XWire::outputIsInverted(XDevice *dev)
+bool XWire::outputIsInverted(XDevice *dev)
 {	int idx;
 
 	if (WFAIL == (idx = getOutputIndex(dev))) fatal("XWire::outputIsInverted: unknown device");
 	return output_is_inv[idx];
 }
 
+bool XWire::outputIsInverted(int idx)
+{
+	return output_is_inv[idx];
+}
+
 // type: CONNECT or DISCON
 void XWire::setDeviceConnections(int type, int idx, XDevice *output_device, int output_id)
 {
@@ -500,7 +482,6 @@ void XWire::setDeviceConnections(int type, int idx, XDevice *output_device, int
 }
 
 // new input device: connect devices
-//void XWire::setDeviceConnection_NI(Device *devi, Device *devo)
 void XWire::setDeviceConnection(int whatsnew, int type, int in_idx, XDevice *output_device, int output_id)
 {	int output_inv_idx = -1;
 
@@ -513,27 +494,31 @@ void XWire::setDeviceConnection(int whatsnew, int type, int in_idx, XDevice *out
 	if (!output_device || whatsnew == NEW_INPUT) {
 		if (input_is_inv[in_idx]) {
 			if (type == CONNECT && !in_inv[in_idx])
-				in_inv[in_idx] = new Device(DeviceType::fINV_INTERNAL);
+				in_inv[in_idx] = m_poDeviceFactory->createDevice(0, DeviceType::fINV_INTERNAL, QPoint(0,0), -1);
 
 			if (type == CONNECT) in_dev[in_idx]->connectDevices(in_inv[in_idx], in_id[in_idx], 0);
 			if (type == DISCONN) in_dev[in_idx]->disconnectDevices(in_inv[in_idx], in_id[in_idx], 0);
 		}
-		if (!output_device) return;
 	}
 
+	if (!output_device)
+		return;
+
 	// output inverter connection/disconnection
 	if (in_idx == -1 || whatsnew == NEW_OUTPUT) {
 		if (output_inv_idx != -1) {
 			if (type == CONNECT) output_device->connectDevices(out_dev[output_inv_idx], output_id, out_id[output_inv_idx]);
 			if (type == DISCONN) output_device->disconnectDevices(out_dev[output_inv_idx], output_id, out_id[output_inv_idx]);
 		}
-		if (in_idx == -1) return;
 	}
 
+	if (in_idx == -1)
+		return;
+
 	// device connection/disconnection
 	if (input_is_inv[in_idx]) {
 		if (type == CONNECT && !in_inv[in_idx])
-			in_inv[in_idx] = new Device(DeviceType::fINV_INTERNAL);
+			in_inv[in_idx] = m_poDeviceFactory->createDevice(0, DeviceType::fINV_INTERNAL, QPoint(0,0), -1);
 
 		if (type == CONNECT) in_inv[in_idx]->connectDevices(output_device, 0, output_id);
 		if (type == DISCONN) in_inv[in_idx]->disconnectDevices(output_device, 0, output_id);
@@ -693,7 +678,7 @@ int XWire::checkShortcut()
 			int output_id = ld->getID1();
 			
 			// one normal device and others (tristate or normal) ...
-			if (!(d->type() == DeviceType::fNET && d->output(output_id) == TRISTATE) &&
+			if (!(d->type() == DeviceType::fNET && d->output(output_id) == Global::Device::TRISTATE) &&
 			    !(d->outputIsTristate(output_id)))
 				return WSHORT;
 			ld = ld->Next();
@@ -729,7 +714,7 @@ void XWire::scanOutputDev()
 			if (output_is_inv[0]) {
 				resetScanAdd(START);
 				if (!out_inv[0])
-					out_inv[0] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
+					out_inv[0] = m_poDeviceFactory->createDevice(0, DeviceType::fINV_INTERNAL, QPoint(0,0), -1);
 				addOutputDev(out_inv[0], 0);
 			} else {
 				resetScanAdd(START);
@@ -741,7 +726,8 @@ void XWire::scanOutputDev()
 			if (output_is_inv[1]) {
 				resetScanAdd(START);
 				if (!out_inv[1])
-					out_inv[1] = new XDevice(DeviceType::fINV_INTERNAL, 0, 0);
+					out_inv[1] = m_poDeviceFactory->createDevice(0, DeviceType::fINV_INTERNAL, QPoint(0,0), -1);
+
 				addOutputDev(out_inv[1], 0);
 			} else {
 				resetScanAdd(START);
@@ -835,39 +821,38 @@ void XWire::resetScan(bool start)
 // WSHORT: runtime shortcut detection
 // WOK:    color changed
 // 0:      nothing changed
-int XWire::setColor(bool force)
-{	KlogicList<XDevice> *ld = wire_devs.First();
-	XDevice *oWireDev;
-	int iOutputID;
-	int found = 0;
+int XWire::setColor(bool bForce)
+{
+	int iFound = 0;
 
+	KlogicList<XDevice> *ld = wire_devs.First();
 	while(ld) {
-		oWireDev = ld->Get();
-		iOutputID = ld->getID1();
-
-		// check wether wire should be fat or normal size
-		if (oWireDev->hasBooleanOutput(iOutputID)) {
-			setLineSize(1);
-		} else {
-			cout << "size 3" << endl;
-			setLineSize(3);
-		}
+		XDevice *oWireDev = ld->Get();
+		int iOutputID = ld->getID1();
 
 		// check here if output is active (tristate!)
-		if (oWireDev->outputIsActive(iOutputID) || force) {
-			if (found) {
-				Wire::color = Qt::cyan;
+		if (oWireDev->outputIsActive(iOutputID) || bForce) {
+			if (iFound) {
+				m_oColor = Qt::cyan;
 				return WSHORT;
 			}
 
-			found++;
-			if (oWireDev->outputChanged() || force || 
-			    (Wire::color != Qt::blue && Wire::color != Qt::red)) {
+			iFound++;
+			if (oWireDev->outputChanged() || bForce || 
+			    (m_oColor != Qt::blue && m_oColor != Qt::red)) {
+				// check wether wire should be fat or normal size
+				if (oWireDev->hasBooleanOutput(iOutputID)) {
+					setLineSize(1);
+				} else {
+					setLineSize(3);
+				}
+
+				// set color of wire
 				if (oWireDev->output(iOutputID)) {
-					Wire::color = Qt::red;
+					m_oColor = Qt::red;
 					return WOK;
 				} else {
-					Wire::color = Qt::blue;
+					m_oColor = Qt::blue;
 					return WOK;
 				}
 			}
@@ -876,10 +861,10 @@ int XWire::setColor(bool force)
 		ld = ld->Next();
 	}
 
-	if (!found) {
-		setLineSize(1);
-		if (Wire::color != Qt::black) {
-			Wire::color = Qt::black;
+	if (!iFound) {
+		if (m_oColor != Qt::black) {
+			setLineSize(1);
+			m_oColor = Qt::black;
 			return WOK;
 		}
 	}
